All notable changes will be noted in this file, whenever a tagged version is made

## [1.0.3] 01/12/2023

Version reviewed for O4a production runs. As new features with respect to 1.0.2, it contains:
- Addition of reference-frame and time-reference to recommended settings https://git.ligo.org/pe/get_eob_settings/-/merge_requests/33
- Addition of NRSur7dq4 constrains plot to report https://git.ligo.org/pe/get_eob_settings/-/merge_requests/34
- Fix prior updating precedence https://git.ligo.org/pe/get_eob_settings/-/merge_requests/28 

## [1.0.4] 24/05/2024

New features with respect to 1.0.3:
- Passing duration of Tukey rollon and post-trigger as parameters. This is for addressing the change in the default Tukey rollon for O4a production runs.